# codat-expenses

<!-- Start SDK Installation -->
## SDK Installation

```bash
pip install codat-expenses
```
<!-- End SDK Installation -->

## SDK Example Usage
<!-- Start SDK Example Usage -->
```python
import codat
from codat.models import operations, shared

s = codat.Codat(
    security=shared.Security(
        auth_header="YOUR_API_KEY_HERE",
    ),
)


req = operations.GetCompanyConfigurationRequest(
    company_id="unde",
)
    
res = s.configuration.get_company_configuration(req)

if res.get_company_configuration_200_application_json_object is not None:
    # handle response
```
<!-- End SDK Example Usage -->

<!-- Start SDK Available Operations -->
## SDK Available Operations


### configuration

* `get_company_configuration` - Get company configuration
* `save_company_configuration` - Set company configuration

### connections

* `create_partnerexpense_connection` - Create Partner Expense connection

### expenses

* `create_expense_dataset` - Create expense-transactions
* `upload_attachment` - Upload attachment

### mapping_options

* `get_mapping_options` - Mapping options

### sync

* `intiate_sync` - Initiate sync

### sync_status

* `get_last_successful_sync` - Last successful sync
* `get_latest_sync` - Latest sync status
* `get_sync_by_id` - Get Sync status
* `list_syncs` - List sync statuses

### transaction_status

* `get_sync_transaction` - Get Sync Transaction
* `get_sync_transactions` - Get Sync transactions
<!-- End SDK Available Operations -->

### SDK Generated by [Speakeasy](https://docs.speakeasyapi.dev/docs/using-speakeasy/client-sdks)
